@@ -1,12 +1,6 @@
 package WWW::MovieReviews::NYT;
 
-use strict; use warnings;
-
-use Carp;
-use Readonly;
-use Data::Dumper;
-use LWP::UserAgent;
-use HTTP::Request::Common;
+$WWW::MovieReviews::NYT::VERSION = '0.05';
 
 =head1 NAME
 
@@ -14,14 +8,18 @@ WWW::MovieReviews::NYT - Interface to NewYorkTimes Movie Reviews API.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
-Readonly my $API_VERSION => 'v2';
-Readonly my $API_URL     =>
-{
+use 5.006;
+use strict; use warnings;
+use Data::Dumper;
+use LWP::UserAgent;
+use HTTP::Request::Common;
+
+my $API_VERSION = 'v2';
+my $API_URL     = {
     1 => "http://api.nytimes.com/svc/movies/${API_VERSION}/reviews/search.xml",
     2 => "http://api.nytimes.com/svc/movies/${API_VERSION}/reviews/",
     3 => "http://api.nytimes.com/svc/movies/${API_VERSION}/reviews/reviewer/",
@@ -30,9 +28,10 @@ Readonly my $API_URL     =>
 
 =head1 DESCRIPTION
 
-With  the  Movie  Reviews  API, you can search New York Times movie reviews by keyword and get
-lists of NYT Critics' Picks.Usage is limited to 5000 requests per day (rate limits are subject
-to change). Currently supports version v2. As of now it only gets result in XML format.
+With the Movie Reviews API,you can search New York Times movie reviews by keyword
+and  get  lists  of  NYT Critics' Picks.Usage is limited to 5000 requests per day
+(rate limits are subject to change). Currently supports version v2.  As of now it
+only gets result in XML format.
 
 The Movie Reviews service uses a RESTful style. Four request types are available:
 
@@ -47,11 +46,11 @@ The Movie Reviews service uses a RESTful style. Four request types are available
 
 =head1 CONSTRUCTOR
 
-The constructor  expects your application API, which you can get it for FREE from The New York
-Times Developer site. You need to create an account first with them. You only need to pick any
-username of your choice and password to get it started.Once you have the account setup you can
-then  request for API Key and accept their Terms and Condition for usage. Here is the link for
-Registration: https://myaccount.nytimes.com/register
+The constructor  expects your application API, which you can get it for FREE from
+The New York Times Developer site. You need to create an account first with them.
+You only need to pick any username of your choice and password to get it started.
+Once you have the account setup you can then request for API Key and accept their
+Terms and Condition for usage. Here is the link for L<registration|https://myaccount.nytimes.com/register>.
 
     use strict; use warnings;
     use WWW::MovieReviews::NYT;
@@ -61,13 +60,10 @@ Registration: https://myaccount.nytimes.com/register
 
 =cut
 
-sub new
-{
-    my $class = shift;
-    my $key   = shift;
+sub new {
+    my ($class, $key) = @_;
 
-    croak("ERROR: API Key is missing.\n")
-        unless defined $key;
+    die("ERROR: API Key is missing.\n") unless defined $key;
     my $self = { key     => $key,
                  browser => LWP::UserAgent->new()
                };
@@ -98,8 +94,8 @@ Search the reviews by given keyword. Possible parameters listed below:
     |                  |                                         | or by-dvd-release-date |
     +------------------+-----------------------------------------+------------------------+
 
-You  can specify  up to  three  search parameters (order, limit and offset do not count toward
-this maximum, but query does).
+You  can specify  up to  three  search parameters (order, limit and offset do not
+count toward this maximum, but query does).
 
     use strict; use warnings;
     use WWW::MovieReviews::NYT;
@@ -111,10 +107,8 @@ this maximum, but query does).
 =cut
 
 # http://api.nytimes.com/svc/movies/v2/reviews/search.xml?query=big&thousand-best=Y&opening-date=1930-01-01;2000-01-01
-sub by_keyword
-{
-    my $self  = shift;
-    my $param = shift;
+sub by_keyword {
+    my ($self, $param) = @_;
 
     _validate_by_keyword_param($param);
 
@@ -131,8 +125,8 @@ sub by_keyword
     $url     .= sprintf("&order=%s", $param->{'order'}) if exists($param->{'order'});
     $request  = HTTP::Request->new(GET=>$url);
     $response = $self->{browser}->request($request);
-    croak("ERROR: Couldn't connect to [$url].\n")
-        unless $response->is_success;
+
+    die("ERROR: Couldn't connect to [$url].\n") unless $response->is_success;
 
     return $response->content;
 }
@@ -162,10 +156,8 @@ Search by reviews and NYT critics. Possible parameters listed below:
 =cut
 
 # http://api.nytimes.com/svc/movies/v2/reviews/dvd-picks.xml?order=by-date&offset=40
-sub by_reviews_critics
-{
-    my $self  = shift;
-    my $param = shift;
+sub by_reviews_critics {
+    my ($self, $param) = @_;
 
     _validate_by_reviews_critics_param($param);
 
@@ -175,8 +167,8 @@ sub by_reviews_critics
     $url     .= sprintf("&order=%s", $param->{'order'}) if exists($param->{'order'});
     $request  = HTTP::Request->new(GET=>$url);
     $response = $self->{browser}->request($request);
-    croak("ERROR: Couldn't connect to [$url].\n")
-        unless $response->is_success;
+
+    die("ERROR: Couldn't connect to [$url].\n") unless $response->is_success;
 
     return $response->content;
 }
@@ -209,10 +201,8 @@ Search by reviewer. Possible parameters listed below:
 =cut
 
 # http://api.nytimes.com/svc/movies/v2/reviews/reviewer/manohla-dargis/all.xml?order=by-title
-sub by_reviewer
-{
-    my $self  = shift;
-    my $param = shift;
+sub by_reviewer {
+    my ($self, $param) = @_;
 
     _validate_by_reviewer_param($param);
 
@@ -223,8 +213,8 @@ sub by_reviewer
     $url     .= sprintf("&order=%s", $param->{'order'}) if exists($param->{'order'});
     $request  = HTTP::Request->new(GET=>$url);
     $response = $self->{browser}->request($request);
-    croak("ERROR: Couldn't connect to [$url].\n")
-        unless $response->is_success;
+
+    die("ERROR: Couldn't connect to [$url].\n") unless $response->is_success;
 
     return $response->content;
 }
@@ -250,10 +240,8 @@ Get reviewer details. Possible parameters listed below:
 =cut
 
 # http://api.nytimes.com/svc/movies/v2/critics/a-o-scott.xml
-sub get_reviewer_details
-{
-    my $self = shift;
-    my $type = shift;
+sub get_reviewer_details {
+    my ($self, $type) = @_;
 
     _validate_resource_type($type);
 
@@ -261,22 +249,19 @@ sub get_reviewer_details
     $url      = sprintf("%s%s.xml?api-key=%s", $API_URL->{4}, $type, $self->{key});
     $request  = HTTP::Request->new(GET=>$url);
     $response = $self->{browser}->request($request);
-    croak("ERROR: Couldn't connect to [$url].\n")
-        unless $response->is_success;
+
+    die("ERROR: Couldn't connect to [$url].\n") unless $response->is_success;
 
     return $response->content;
 }
 
-sub _validate_by_keyword_param
-{
-    my $param = shift;
-    croak("ERROR: Missing input parameters.\n")
-        unless defined $param;
-    croak("ERROR: Input param has to be a ref to HASH.\n")
-        if (ref($param) ne 'HASH');
-    croak("ERROR: Missing key query.\n")
-        unless exists($param->{'query'});
-    croak("ERROR: Invalid value for key reviewer [". $param->{'reviewer'} . "].\n")
+sub _validate_by_keyword_param {
+    my ($param) = @_;
+
+    die("ERROR: Missing input parameters.\n") unless defined $param;
+    die("ERROR: Input param has to be a ref to HASH.\n") if (ref($param) ne 'HASH');
+    die("ERROR: Missing key query.\n") unless exists($param->{'query'});
+    die("ERROR: Invalid value for key reviewer [". $param->{'reviewer'} . "].\n")
         if (defined($param->{'reviewer'}) && ($param->{'reviewer'} !~ /\b[a-z\.\-]+\b/i));
 
     _validate_y_n('critics-pick', $param->{'critics-pick'});
@@ -288,32 +273,26 @@ sub _validate_by_keyword_param
     _validate_key_order($param->{'order'});
 }
 
-sub _validate_by_reviews_critics_param
-{
-    my $param = shift;
-    croak("ERROR: Missing input parameters.\n")
-        unless defined $param;
-    croak("ERROR: Input param has to be a ref to HASH.\n")
-        if (ref($param) ne 'HASH');
-    croak("ERROR: Missing key resource-type.\n")
-        unless exists($param->{'resource-type'});
-    croak("ERROR: Invalid value for key resource-type [". $param->{'resource-type'} . "].\n")
+sub _validate_by_reviews_critics_param {
+    my ($param) = @_;
+
+    die("ERROR: Missing input parameters.\n") unless defined $param;
+    die("ERROR: Input param has to be a ref to HASH.\n") if (ref($param) ne 'HASH');
+    die("ERROR: Missing key resource-type.\n") unless exists($param->{'resource-type'});
+    die("ERROR: Invalid value for key resource-type [". $param->{'resource-type'} . "].\n")
         unless ($param->{'resource-type'} =~ /\ball\b|\bpicks\b|\bdvd\-picks\b/i);
 
     _validate_key_offset($param->{'offset'});
     _validate_key_order($param->{'order'});
 }
 
-sub _validate_by_reviewer_param
-{
-    my $param = shift;
-    croak("ERROR: Missing input parameters.\n")
-        unless defined $param;
-    croak("ERROR: Input param has to be a ref to HASH.\n")
-        if (ref($param) ne 'HASH');
-    croak("ERROR: Missing key reviewer-name.\n")
-        unless exists($param->{'reviewer-name'});
-    croak("ERROR: Invalid value for key reviewer-name [". $param->{'reviewer-name'} . "].\n")
+sub _validate_by_reviewer_param {
+    my ($param) = @_;
+
+    die("ERROR: Missing input parameters.\n") unless defined $param;
+    die("ERROR: Input param has to be a ref to HASH.\n") if (ref($param) ne 'HASH');
+    die("ERROR: Missing key reviewer-name.\n") unless exists($param->{'reviewer-name'});
+    die("ERROR: Invalid value for key reviewer-name [". $param->{'reviewer-name'} . "].\n")
         unless ($param->{'reviewer-name'} =~ /\b[a-z\.\-]+\b/i);
 
     _validate_y_n('critics-pick', $param->{'critics-pick'});
@@ -321,10 +300,9 @@ sub _validate_by_reviewer_param
     _validate_key_order($param->{'order'});
 }
 
-sub _validate_date
-{
-    my $key   = shift;
-    my $value = shift;
+sub _validate_date {
+    my ($key, $value) = @_;
+
     return unless defined $value;
 
     my @values;
@@ -334,29 +312,26 @@ sub _validate_date
     :
     (@values = ($value));
 
-    foreach (@values)
-    {
-        croak("ERROR: Invalid value for key $key [$value].\n")
+    foreach (@values) {
+        die("ERROR: Invalid value for key $key [$value].\n")
             if (defined($_) && ($_ !~ /^\d{4}\-\d{2}\-\d{2}$/));
     }
 }
 
-sub _validate_y_n
-{
-    my $key   = shift;
-    my $value = shift;
+sub _validate_y_n {
+    my ($key, $value) = @_;
+
     return unless defined $value;
 
-    croak("ERROR: Invalid value for key $key [$value].\n")
-        if (defined($value) && ($value !~ /^[y|n]$/i));
+    die("ERROR: Invalid value for key $key [$value].\n") if (defined($value) && ($value !~ /^[y|n]$/i));
 }
 
-sub _validate_key_offset
-{
-    my $offset = shift;
+sub _validate_key_offset {
+    my ($offset) = @_;
+
     return unless defined $offset;
 
-    croak("ERROR: Invalid value for key offset [$offset].\n")
+    die("ERROR: Invalid value for key offset [$offset].\n")
         unless (defined($offset)
                 &&
                 ($offset =~ /^\d{1,}$/)
@@ -364,21 +339,20 @@ sub _validate_key_offset
                 (($offset == 0) || ($offset%20 == 0)));
 }
 
-sub _validate_key_order
-{
-    my $order = shift;
-    croak("ERROR: Invalid value for key order [$order].\n")
+sub _validate_key_order {
+    my ($order) = @_;
+
+    die("ERROR: Invalid value for key order [$order].\n")
         if (defined($order)
             &&
-           ($order !~ /\bby\-title\b|\bby\-publication\-date\b|\bby\-opening\-date\b|\bby\-dvd\-release\-date\b/i));
+            ($order !~ /\bby\-title\b|\bby\-publication\-date\b|\bby\-opening\-date\b|\bby\-dvd\-release\-date\b/i));
 }
 
-sub _validate_resource_type
-{
-    my $type = shift;
-    croak("ERROR: Missing key resource-type.\n")
-        unless defined $type;
-    croak("ERROR: Invalid value for key resource-type [$type].\n")
+sub _validate_resource_type {
+    my ($type) = @_;
+
+    die("ERROR: Missing key resource-type.\n") unless defined $type;
+    die("ERROR: Invalid value for key resource-type [$type].\n")
         unless ($type =~ /\ball\b|\bfull\-time\b|\bpart\-time\b|\breviewer\b|[a..z\.\-]+/i);
 }
 
@@ -386,6 +360,10 @@ sub _validate_resource_type
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-MovieReviews-NTY>
+
 =head1 BUGS
 
 Please  report  any bugs or feature requests to C<bug-www-moviereviews-nyt at rt.cpan.org>, or
@@ -438,4 +416,4 @@ without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 
 =cut
 
-1; # End of WWW::MovieReviews::NYT
\ No newline at end of file
+1; # End of WWW::MovieReviews::NYT
